"Harumaru" Sphinx Documentation Themes
======================================

This is a collection of themes for use with Sphinx documentation projects.

Installation
------------

Installation from PyPI is fairly straightforward:

1. Install the package::

      $ pip install sphinx_harumaru_themes

2. Edit the ``conf.py`` configuration file to point to the theme::

      html_theme = 'haruki_light'

